.. _api-shortcuts:

Shortcuts
=========

.. automodule:: guardian.shortcuts


.. _api-shortcuts-assign:

assign
------

.. autofunction:: guardian.shortcuts.assign

.. _api-shortcuts-remove_perm:

remove_perm
-----------

.. autofunction:: guardian.shortcuts.remove_perm

.. _api-shortcuts-get_perms:

get_perms
---------

.. autofunction:: guardian.shortcuts.get_perms


.. _api-shortcuts-get_perms_for_model:

get_perms_for_model
-------------------

.. autofunction:: guardian.shortcuts.get_perms_for_model

get_users_with_perms
--------------------

.. autofunction:: guardian.shortcuts.get_users_with_perms


get_groups_with_perms
---------------------

.. autofunction:: guardian.shortcuts.get_groups_with_perms

